==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/Zadluzenie.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.AktualnoscZadluzenia;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class Zadluzenie extends GenericDPSObject {
    /**
     * ZADLUZENIE.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * ZADLUZENIE.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * ZADLUZENIE.MIESIAC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer miesiac;

    /**
     * ZADLUZENIE.ROK
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer rok;

    /**
     * ZADLUZENIE.AKTUALNOSC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private AktualnoscZadluzenia aktualnosc;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZADLUZENIE.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ZADLUZENIE.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ZADLUZENIE.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * ZADLUZENIE.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return ZADLUZENIE.MIESIAC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getMiesiac() {
        return miesiac;
    }

    /**
     * ZADLUZENIE.MIESIAC
     *
     * @param miesiac
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setMiesiac(Integer miesiac) {
        this.miesiac = miesiac;
    }

    /**
     * @return ZADLUZENIE.ROK
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getRok() {
        return rok;
    }

    /**
     * ZADLUZENIE.ROK
     *
     * @param rok
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRok(Integer rok) {
        this.rok = rok;
    }

    /**
     * @return ZADLUZENIE.AKTUALNOSC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public AktualnoscZadluzenia getAktualnosc() {
        return aktualnosc;
    }

    /**
     * ZADLUZENIE.AKTUALNOSC
     *
     * @param aktualnosc
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setAktualnosc(AktualnoscZadluzenia aktualnosc) {
        this.aktualnosc = aktualnosc;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Zadluzenie other = (Zadluzenie) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getMiesiac() == null ? other.getMiesiac() == null : this.getMiesiac().equals(other.getMiesiac()))
            && (this.getRok() == null ? other.getRok() == null : this.getRok().equals(other.getRok()))
            && (this.getAktualnosc() == null ? other.getAktualnosc() == null : this.getAktualnosc().equals(other.getAktualnosc()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getMiesiac() == null) ? 0 : getMiesiac().hashCode());
        result = prime * result + ((getRok() == null) ? 0 : getRok().hashCode());
        result = prime * result + ((getAktualnosc() == null) ? 0 : getAktualnosc().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", miesiac=").append(miesiac);
        sb.append(", rok=").append(rok);
        sb.append(", aktualnosc=").append(aktualnosc);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/Zadluzenie.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.AktualnoscZadluzenia;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class Zadluzenie extends GenericDPSObject {
    /**
     * ZADLUZENIE.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * ZADLUZENIE.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * ZADLUZENIE.MIESIAC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer miesiac;

    /**
     * ZADLUZENIE.ROK
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer rok;

    /**
     * ZADLUZENIE.AKTUALNOSC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private AktualnoscZadluzenia aktualnosc;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZADLUZENIE.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ZADLUZENIE.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ZADLUZENIE.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * ZADLUZENIE.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return ZADLUZENIE.MIESIAC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getMiesiac() {
        return miesiac;
    }

    /**
     * ZADLUZENIE.MIESIAC
     *
     * @param miesiac
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setMiesiac(Integer miesiac) {
        this.miesiac = miesiac;
    }

    /**
     * @return ZADLUZENIE.ROK
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getRok() {
        return rok;
    }

    /**
     * ZADLUZENIE.ROK
     *
     * @param rok
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRok(Integer rok) {
        this.rok = rok;
    }

    /**
     * @return ZADLUZENIE.AKTUALNOSC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public AktualnoscZadluzenia getAktualnosc() {
        return aktualnosc;
    }

    /**
     * ZADLUZENIE.AKTUALNOSC
     *
     * @param aktualnosc
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setAktualnosc(AktualnoscZadluzenia aktualnosc) {
        this.aktualnosc = aktualnosc;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Zadluzenie other = (Zadluzenie) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getMiesiac() == null ? other.getMiesiac() == null : this.getMiesiac().equals(other.getMiesiac()))
            && (this.getRok() == null ? other.getRok() == null : this.getRok().equals(other.getRok()))
            && (this.getAktualnosc() == null ? other.getAktualnosc() == null : this.getAktualnosc().equals(other.getAktualnosc()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getMiesiac() == null) ? 0 : getMiesiac().hashCode());
        result = prime * result + ((getRok() == null) ? 0 : getRok().hashCode());
        result = prime * result + ((getAktualnosc() == null) ? 0 : getAktualnosc().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", miesiac=").append(miesiac);
        sb.append(", rok=").append(rok);
        sb.append(", aktualnosc=").append(aktualnosc);
        sb.append("]");
        return sb.toString();
    }
}
